/*
 * Copyright 2005 Sascha Weinreuter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.lang.xpath.xslt.psi.impl;

import org.intellij.lang.xpath.xslt.XsltSupport;
import org.intellij.lang.xpath.xslt.psi.XsltElement;
import org.intellij.lang.xpath.xslt.psi.XsltElementFactory;

import com.intellij.openapi.components.ApplicationComponent;
import com.intellij.openapi.util.Key;
import com.intellij.psi.xml.XmlTag;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.Nullable;
import org.jetbrains.annotations.NotNull;

class XsltElementFactoryImpl extends XsltElementFactory implements ApplicationComponent {
    private static final Key<XsltElement> WRAPPER = Key.create("WRAPPER");

    @NotNull
    @NonNls
    public String getComponentName() {
        return "XSLT-Support.ElementFactory";
    }

    public void initComponent() {
    }

    public void disposeComponent() {
    }

    @SuppressWarnings({ "unchecked" })
    @Override
    public XsltElement wrapElement(XmlTag target) {
        assert target.isValid();

        final XsltElement wrapper = target.getUserData(WRAPPER);
        if (wrapper != null && wrapper.isValid()) {
            return wrapper;
        }
        assert XsltSupport.isXsltTag(target);

        final XsltElement element;
        if (XsltSupport.isTemplate(target, false)) {
            element = new XsltTemplateImpl(target);
        } else if (XsltSupport.isVariable(target)) {
            element = new XsltVariableImpl(target);
        } else if (XsltSupport.isParam(target)) {
            element = new XsltParameterImpl(target);
        } else if (XsltSupport.isTemplateCall(target)) {
            element = new XsltCallTemplateImpl(target);
        } else if (XsltSupport.isApplyTemplates(target)) {
            element = new XsltApplyTemplatesImpl(target);
        } else if ("with-param".equals(target.getLocalName())) {
            element = new XsltWithParamImpl(target);
        } else if (XsltSupport.isXsltRootTag(target)) {
            element = new XsltStylesheetImpl(target);
        } else {
            element = new XsltElementImpl(target) {
                @Nullable
                public String toString() {
                    return "Unrecognized tag: " + getTag().getName();
                }
            };
        }

        target.putUserData(WRAPPER, element);
        return element;
    }
}
