/*
 * Copyright 2005 Sascha Weinreuter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.lang.xpath.xslt.quickfix;

import com.intellij.codeInsight.intention.IntentionAction;
import com.intellij.codeInsight.template.TemplateBuilder;
import com.intellij.openapi.editor.Editor;
import com.intellij.openapi.fileTypes.StdFileTypes;
import com.intellij.psi.PsiElement;
import com.intellij.psi.PsiFile;
import com.intellij.psi.xml.XmlTag;
import com.intellij.util.LocalTimeCounter;
import org.jetbrains.annotations.NotNull;

abstract class AbstractFix implements IntentionAction {
    @NotNull
    public String getFamilyName() {
        final int i = getClass().getName().lastIndexOf('.');
        return "XSLT " + getClass().getName().substring(i + 1).replaceAll("Fix$", "").replaceAll("(\\p{Lower}+)(\\p{Upper})", "$1 $2");
    }

    public boolean startInWriteAction() {
        return true;
    }

    protected static void moveTo(Editor editor, XmlTag xmlTag) {
        editor.getCaretModel().moveToOffset(xmlTag.getTextRange().getStartOffset());
    }

    protected static void deleteFromDocument(Editor editor, PsiElement dummy) {
        editor.getDocument().deleteString(dummy.getTextRange().getStartOffset(), dummy.getTextRange().getEndOffset());
    }

    protected static TemplateBuilder createTemplateBuilder(XmlTag xmlTag) {
        final PsiFile psiFile = xmlTag.getManager().getElementFactory().createFileFromText("dummy.xml", StdFileTypes.XML, xmlTag.getText(), LocalTimeCounter.currentTime(), true, false);
        return new TemplateBuilder(psiFile);
    }
}