/*
 * Copyright 2005 Sascha Weinreuter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.lang.xpath.xslt.quickfix;

import org.intellij.lang.xpath.xslt.XsltSupport;
import org.intellij.lang.xpath.xslt.psi.XsltElement;
import org.intellij.lang.xpath.xslt.psi.XsltElementFactory;

import com.intellij.psi.PsiNamedElement;
import com.intellij.psi.xml.XmlAttribute;
import com.intellij.psi.xml.XmlTag;
import org.jetbrains.annotations.Nullable;

public class DeleteUnusedVariableFix extends DeleteUnusedElementBase {

    protected String getType() {
        return "Variable";
    }

    @Nullable
    protected PsiNamedElement getElement(@Nullable XmlTag tag) {
        if (tag != null) {
            final XmlAttribute attribute = tag.getAttribute("name", null);
            if (attribute != null && XsltSupport.isVariable(attribute)) {
                //noinspection RedundantCast
                return (PsiNamedElement)(XsltElement)XsltElementFactory.getInstance().wrapElement(tag);
            }
        }
        return null;
    }
}
