/*
 * Copyright 2006 Sascha Weinreuter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.lang.xpath.xslt.run;

import com.intellij.diagnostic.logging.AdditionalTabComponent;
import com.intellij.execution.filters.TextConsoleBuilderFactory;
import com.intellij.execution.ui.ConsoleView;
import com.intellij.openapi.fileTypes.FileType;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.editor.ex.EditorEx;
import com.intellij.openapi.editor.ex.util.LexerEditorHighlighter;
import com.intellij.openapi.actionSystem.DataProvider;
import com.intellij.openapi.actionSystem.DataConstants;

import javax.swing.*;
import java.awt.*;

public class HighlightingOutputConsole extends AdditionalTabComponent {
    public static final String TAB_TITLE = "XSLT Output";

    private final ConsoleView myConsole;

    public HighlightingOutputConsole(Project project, FileType fileType) {
        super(new BorderLayout());

        myConsole = TextConsoleBuilderFactory.getInstance().createBuilder(project).getConsole();

        add(myConsole.getComponent(), BorderLayout.CENTER);

        final EditorEx editorEx = ((EditorEx)((DataProvider)myConsole).getData(DataConstants.EDITOR));
        assert editorEx != null;

        editorEx.setHighlighter(new LexerEditorHighlighter(fileType.getHighlighter(project, null), editorEx.getColorsScheme()));
    }

    public void addNotify() {
        super.addNotify();
        
        final Container parent = getParent();
        if (parent instanceof JTabbedPane) {
            // run
            ((JTabbedPane)parent).setSelectedComponent(this);
        } else if (parent != null) {
            // debug
            final Container grandparent = parent.getParent();
            if (grandparent instanceof JTabbedPane) {
                ((JTabbedPane)grandparent).setSelectedComponent(parent);
            }
        }
    }

    public String getTabTitle() {
        return TAB_TITLE;
    }

    public void dispose() {
        myConsole.dispose();
    }

    public ConsoleView getConsole() {
        return myConsole;
    }
}
