/*
 * Copyright 2005 Sascha Weinreuter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.lang.xpath.xslt.util;

import com.intellij.codeInsight.javadoc.JavaDocManager;
import com.intellij.psi.PsiElement;

public class CompositeDocumentationProvider implements JavaDocManager.DocumentationProvider {
    private final JavaDocManager.DocumentationProvider myProvider1;
    private final JavaDocManager.DocumentationProvider myProvider2;

    public CompositeDocumentationProvider(JavaDocManager.DocumentationProvider provider1, JavaDocManager.DocumentationProvider provider2) {
        myProvider1 = provider1;
        myProvider2 = provider2;
    }

    public String getUrlFor(PsiElement psiElement, PsiElement psiElement1) {
        final String url = myProvider1.getUrlFor(psiElement, psiElement1);
        return url != null ? url : myProvider2.getUrlFor(psiElement, psiElement1);
    }

    public String generateDoc(PsiElement psiElement, PsiElement psiElement1) {
        final String s = myProvider1.generateDoc(psiElement, psiElement1);
        return s != null && s.length() > 0 ? s : myProvider2.generateDoc(psiElement, psiElement1);
    }

    public PsiElement getDocumentationElementForLookupItem(Object object, PsiElement psiElement) {
        final PsiElement element = myProvider1.getDocumentationElementForLookupItem(object, psiElement);
        return element != null ? element : myProvider2.getDocumentationElementForLookupItem(element, element);
    }

    public PsiElement getDocumentationElementForLink(String string, PsiElement psiElement) {
        final PsiElement element = myProvider1.getDocumentationElementForLink(string, psiElement);
        return element != null ? element : myProvider2.getDocumentationElementForLink(string, element);
    }
}
