/*
 * Copyright 2005 Sascha Weinreuter
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.intellij.lang.xpath.xslt.validation;

import org.intellij.lang.xpath.xslt.util.ElementProcessor;
import org.intellij.lang.xpath.xslt.XsltSupport;
import org.intellij.lang.xpath.xslt.quickfix.RenameVariableFix;
import com.intellij.psi.xml.XmlTag;
import com.intellij.psi.xml.XmlAttribute;
import com.intellij.psi.PsiElement;
import com.intellij.codeInsight.daemon.impl.HighlightInfo;
import com.intellij.codeInsight.daemon.impl.HighlightInfoType;
import com.intellij.codeInsight.daemon.impl.quickfix.QuickFixAction;
import com.intellij.codeInsight.daemon.impl.analysis.HighlightInfoHolder;

// TODO: include/import semantics are not 100% correct currently
final class DeclarationChecker extends ElementProcessor<XmlTag> {
    boolean myContinue = true;
    private final boolean myVar;
    private final String myValue;
    private final PsiElement myToken;
    private final HighlightInfoHolder myHighlightInfoHolder;

    public DeclarationChecker(boolean var, XmlTag tag, String value, HighlightInfoHolder highlightInfoHolder) {
        super(tag);
        myVar = var;
        myValue = value;
        myHighlightInfoHolder = highlightInfoHolder;
        final XmlAttribute attribute = tag.getAttribute("name", null);
        assert attribute != null;
        myToken = XsltSupport.getAttValueToken(attribute);
    }

    protected boolean followImport() {
        return false;
    }

    protected void processTemplate(XmlTag tag) {
        if (!myVar) {
            processTag(tag);
        }
    }

    protected void processVarOrParam(XmlTag tag) {
        if (myVar) {
            processTag(tag);
        }
    }

    protected boolean shouldContinue() {
        return myContinue;
    }

    private void processTag(XmlTag t) {
        if (t != myRoot) {
            if (myValue.equals(t.getAttributeValue("name"))) {
                if (t.getParent() == myRoot.getParent() || !myVar || isInclude()) {
                    myHighlightInfoHolder.add(HighlightInfo.createHighlightInfo(HighlightInfoType.ERROR, myToken, "Duplicate declaration"));
                } else {
                    final HighlightInfo highlightInfo = HighlightInfo.createHighlightInfo(HighlightInfoType.WARNING, myToken, "Variable '" + myValue + "' shadows variable in outer scope");
                    QuickFixAction.registerQuickFixAction(highlightInfo, new RenameVariableFix(myRoot, "local"));
                    QuickFixAction.registerQuickFixAction(highlightInfo, new RenameVariableFix(t, "outer"));
                    myHighlightInfoHolder.add(highlightInfo);
                }
                myContinue = false;
            }
        }
    }
}
